# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.with_limits import WithLimits

class TestWithLimits(unittest.TestCase):
    """WithLimits unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WithLimits:
        """Test WithLimits
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WithLimits`
        """
        model = WithLimits()
        if include_optional:
            return WithLimits(
                account_limits = 56,
                applies_to = '',
                block = True,
                consumption = 1,
                id = 56,
                limits = 56,
                reference_id = 56,
                reference_type = 'SUBSCRIPTION',
                remaining = 56,
                resets_in_seconds = 56,
                subscription_limits = 56
            )
        else:
            return WithLimits(
                applies_to = '',
        )
        """

    def testWithLimits(self):
        """Test WithLimits"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
