# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.scope import Scope

class TestScope(unittest.TestCase):
    """Scope unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testScope(self):
        """Test Scope"""
        # inst = Scope()

if __name__ == '__main__':
    unittest.main()
