# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.api.content_generation_word_biases_api import ContentGenerationWordBiasesApi


class TestContentGenerationWordBiasesApi(unittest.TestCase):
    """ContentGenerationWordBiasesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ContentGenerationWordBiasesApi()

    def tearDown(self) -> None:
        pass

    def test_create_word(self) -> None:
        """Test case for create_word

        Create
        """
        pass

    def test_create_words(self) -> None:
        """Test case for create_words

        Update for prompt
        """
        pass

    def test_create_words_from_csv(self) -> None:
        """Test case for create_words_from_csv

        Update from CSV
        """
        pass

    def test_delete_word(self) -> None:
        """Test case for delete_word

        Delete
        """
        pass

    def test_list_words(self) -> None:
        """Test case for list_words

        List
        """
        pass

    def test_update_word(self) -> None:
        """Test case for update_word

        Update
        """
        pass


if __name__ == '__main__':
    unittest.main()
